@@ -841,7 +841,7 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="../makeLiveStick.py" line="197"/>
         <source>the targetted USB stick</source>
-        <translation>la clé USB cible</translation>
+        <translation type="obsolete">la clé USB cible</translation>
     </message>
     <message>
         <location filename="../makeLiveStick.py" line="89"/>
@@ -849,7 +849,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Démontage de {}</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="256"/>
+        <location filename="../makeLiveStick.py" line="264"/>
         <source>Copying {0} to {1} ...</source>
         <translation>Copie de {0} vers {1} ...</translation>
     </message>
@@ -864,7 +864,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Création de la partition {}3 pour supporter la persistance</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="331"/>
+        <location filename="../makeLiveStick.py" line="339"/>
         <source>This partition is adjusted to use all the remaining space on {}</source>
         <translation>On ajuste cette partition pour utiliser la place restante sur {}</translation>
     </message>
@@ -879,7 +879,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Initialisation de la troisième partition à l'aide de rw.tar.gz</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="423"/>
+        <location filename="../makeLiveStick.py" line="431"/>
         <source>Ready. Total time: {}</source>
         <translation>Terminé. Durée totale : {}</translation>
     </message>
@@ -914,7 +914,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Initialisation de la quatrième partition à l'aide de rw.tar.gz</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="250"/>
+        <location filename="../makeLiveStick.py" line="258"/>
         <source>Delete the partition {}{}, to create it again</source>
         <translation>Suppression de la partition {}{}, pour la créer à nouveau</translation>
     </message>
@@ -929,12 +929,12 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Création de la partition {}3, format VFAT, taille {}Gio</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="235"/>
+        <location filename="../makeLiveStick.py" line="243"/>
         <source>The disk is too small ({} GiB) to contain the ISO image ({} GiB) plus at least 1 GB for the persistence</source>
         <translation>Le disque est manque de capacité ({} Go) pour contenir l'image ISO ({} Go) plus au moins 1 Go pour la persistance</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="240"/>
+        <location filename="../makeLiveStick.py" line="248"/>
         <source>The size of the VFAT partition has been shrinked down to {} GB</source>
         <translation>La taille de la partition VFAT a été diminuée à {} Go</translation>
     </message>
@@ -974,65 +974,70 @@ p, li { white-space: pre-wrap; }
         <translation>Sur le point de lancer la commande {cmd}</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="274"/>
+        <location filename="../makeLiveStick.py" line="282"/>
         <source>Create the extended partition {}p3</source>
         <translation>Création de la partition étendue {}p3</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="276"/>
+        <location filename="../makeLiveStick.py" line="284"/>
         <source>Create the extended partition {}3</source>
         <translation>Création de la partition étendue {}3</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="294"/>
+        <location filename="../makeLiveStick.py" line="302"/>
         <source>Create Extended Partition</source>
         <translation>Création de la partition étendue</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="299"/>
+        <location filename="../makeLiveStick.py" line="307"/>
         <source>Create the partition {}p5 for VFAT data, using {}GiB</source>
         <translation>Création de la partition {}p5 pour les données VFAT, avec {} Go</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="301"/>
+        <location filename="../makeLiveStick.py" line="309"/>
         <source>Create the partition {}5 for VFAT data, using {}GiB</source>
         <translation>Création de la partition {}5, format VFAT, taille {}Gio</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="321"/>
+        <location filename="../makeLiveStick.py" line="329"/>
         <source>Create Vfat</source>
         <translation>Création de la partition Vfat</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="328"/>
+        <location filename="../makeLiveStick.py" line="336"/>
         <source>Create the partition {}p6 to support persistence</source>
         <translation>Création de la partition {}p6 pour supporter la persistance</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="330"/>
+        <location filename="../makeLiveStick.py" line="338"/>
         <source>Create the partition {}6 to support persistence</source>
         <translation>Création de la partition {}6 pour supporter la persistance</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="353"/>
+        <location filename="../makeLiveStick.py" line="361"/>
         <source>Create Ext4</source>
         <translation>Création de la partition Ext4</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="378"/>
+        <location filename="../makeLiveStick.py" line="386"/>
         <source>Format vfat and ext4 partitions</source>
         <translation>Format des partitions Vfat et Ext4</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="392"/>
+        <location filename="../makeLiveStick.py" line="400"/>
         <source>Create the file persistence.conf on the last partition</source>
         <translation>Création du fichier persistence.conf sur la dernière partition</translation>
     </message>
     <message>
-        <location filename="../makeLiveStick.py" line="403"/>
+        <location filename="../makeLiveStick.py" line="411"/>
         <source>Pre-seed the last partition with rw.tar.gz</source>
         <translation>Pré-ensemencenment de la dernière partition avec le fichier rw.tar.gz</translation>
     </message>
+    <message>
+        <location filename="../makeLiveStick.py" line="197"/>
+        <source>the targetted USB stick, or the name of the file to create in case of a simulation</source>
+        <translation>La clé USB ciblée, ou le nom d'un fichier à créer dans le cas d'une simulation</translation>
+    </message>
 </context>
 <context>
     <name>Tool</name>
