@@ -80,6 +80,15 @@ def cloneHDD(own_device):
     cmd = ["blockdev", "--rereadpt", "/dev/sda"]
     call(cmd)
     time.sleep(2)
+
+    # modify the file /syslinux/live.cfg to erase occurences of
+    # persistence-media=...
+    cmd = ["mount", "/dev/sda1", "/mnt"]
+    call(cmd)
+    cmd = ["sed", "-i", "s/persistence-media=removable-usb //", "/mnt/syslinux/live.cfg"]
+    call(cmd)
+    cmd = ["umount", "/mnt"]
+    call(cmd)
     
     ## commands for sfdisk:
     #### dump partitions, and forget everything after /dev/sda1
