@@ -3,6 +3,7 @@
 """
 sense the own system when cloning from a Freeduc drive
 """
+from subprocess import run
 
 def ownDevice(blockSize = 4194304):
     """
@@ -16,7 +17,7 @@ def ownDevice(blockSize = 4194304):
     device = completed.stdout.strip()
     if device == "":
         raise Exception("No own device, are we running a non-Freeduc system?")
-    cmd=f"sfdisk -l {device} | awk '{{print $4}}'"
+    cmd=f"LANG=C sfdisk -l {device} | head -n1|  awk '{{print $7}}'"
     completed = run(cmd, shell=True, capture_output=True, encoding="utf-8")
     sectors=int(completed.stdout.strip())
     count = 1 + sectors*512//blockSize # convert 512 B sectors to 4 MiB blocks
