@@ -226,6 +226,10 @@ class UDisksBackend:
                 if 'UDisks2.Error.AlreadyMounted' in e.message:
                     m=re.match(r".*already mounted[^/]*([^\']+).*",e.message)
                     return m.group(1)
+                elif 'UDisks2.Error.Failed' in e.message:
+                    m = re.match(".*: (/dev/[^ ]+) already mounted .*",
+                                 e.message)
+                    return m.group(1)
                 elif 'UDisks2.Error.DeviceBusy' in e.message:
                     pass
                 else:
@@ -837,7 +841,7 @@ class Available (UDisksBackend):
         :rtype: uDisk2
         """
         if self.access=="disk" or self.access=="all":
-            path=self.targets.keys()[n]
+            path=list(self.targets.keys())[n]
         elif self.access=="firstFat":
             path=self.firstFats[n]
         return self.targets[path]
